RGBLedMatrixOptions

Struct RGBLedMatrixOptions 

#[repr(C)]
pub struct RGBLedMatrixOptions {
Show 20 fields pub hardware_mapping: *const c_char, pub rows: c_int, pub cols: c_int, pub chain_length: c_int, pub parallel: c_int, pub pwm_bits: c_int, pub pwm_lsb_nanoseconds: c_int, pub pwm_dither_bits: c_int, pub brightness: c_int, pub scan_mode: c_int, pub row_address_type: c_int, pub multiplexing: c_int, pub disable_hardware_pulsing: bool, pub show_refresh_rate: bool, pub inverse_colors: bool, pub led_rgb_sequence: *const c_char, pub pixel_mapper_config: *const c_char, pub panel_type: *const c_char, pub limit_refresh_rate_hz: c_int, pub disable_busy_waiting: bool,
}
Parameters to create a new matrix.

To get the defaults, non-set values have to be initialized to zero, so you should zero out this struct before setting anything.

Fields

hardware_mapping: *const c_charrows: c_intcols: c_intchain_length: c_intparallel: c_intpwm_bits: c_intpwm_lsb_nanoseconds: c_intpwm_dither_bits: c_intbrightness: c_intscan_mode: c_introw_address_type: c_intmultiplexing: c_intdisable_hardware_pulsing: bool

The following boolean flags are off by default

show_refresh_rate: boolinverse_colors: boolled_rgb_sequence: *const c_charpixel_mapper_config: *const c_charpanel_type: *const c_charlimit_refresh_rate_hz: c_intdisable_busy_waiting: bool